pub struct Cli {
pub command: Option<Commands>,
}Expand description
Parsed command-line arguments for the rbackup binary.
Use Cli::parse() (provided by clap) to obtain a populated instance.
If no subcommand is provided the command field will be None and the
caller can decide how to react (for example: print help and exit 0).
Examples
use clap::Parser;
use rbackup::cli::Cli;
// Let clap parse arguments from the current process
let cli = Cli::parse();
match cli.command {
Some(rbackup::cli::Commands::Copy { .. }) => println!("Copy command chosen"),
Some(rbackup::cli::Commands::Config { .. }) => println!("Config command chosen"),
None => println!("No subcommand provided"),
}Fields
command: Option<Commands>Selected subcommand and its options. Optional to allow showing help without Clap treating the absence of a subcommand as an error.