pub struct ExcludeMatcher {
pub combined: GlobSet,
pub singles: Vec<(String, GlobSet)>,
}Expand description
Pattern matcher for exclude lists.
The matcher holds a combined GlobSet for fast checking and a vector of
single-pattern GlobSets so the code can determine which pattern matched
(useful for logging the pattern that caused a skip).
Fields
combined: GlobSetsingles: Vec<(String, GlobSet)>Implementations